## Template for feature request

Thank you for taking the time to fill out this feature request template!

### Title
Please provide a title or name for this issue.

### Describe the feature you'd like to see
Please provide a clear and concise description of why this new feature would be useful. 
Also, we'd appreciate any implementation ideas and references you already have.

### Checklist

- [ ] I have checked the list of [existing issues](https://gitlab.tudelft.nl/demoses/cronian/-/issues) and couldn't find an issue about this.


/label ~Enhancement